==> logs-1.101.0-sources.jar: software/amazon/awscdk/services/logs/MetricFilterProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for a MetricFilter.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:41.998Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.MetricFilterProps")
@software.amazon.jsii.Jsii.Proxy(MetricFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MetricFilterProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.logs.MetricFilterOptions {

    /**
     * The log group to create the filter on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getLogGroup();

    /**
     * @return a {@link Builder} of {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MetricFilterProps> {
        private software.amazon.awscdk.services.logs.ILogGroup logGroup;
        private software.amazon.awscdk.services.logs.IFilterPattern filterPattern;
        private java.lang.String metricName;
        private java.lang.String metricNamespace;
        private java.lang.Number defaultValue;
        private java.lang.String metricValue;

        /**
         * Sets the value of {@link MetricFilterProps#getLogGroup}
         * @param logGroup The log group to create the filter on. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroup(software.amazon.awscdk.services.logs.ILogGroup logGroup) {
            this.logGroup = logGroup;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getFilterPattern}
         * @param filterPattern Pattern to search for log events. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filterPattern(software.amazon.awscdk.services.logs.IFilterPattern filterPattern) {
            this.filterPattern = filterPattern;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricName}
         * @param metricName The name of the metric to emit. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricName(java.lang.String metricName) {
            this.metricName = metricName;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricNamespace}
         * @param metricNamespace The namespace of the metric to emit. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricNamespace(java.lang.String metricNamespace) {
            this.metricNamespace = metricNamespace;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getDefaultValue}
         * @param defaultValue The value to emit if the pattern does not match a particular event.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultValue(java.lang.Number defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricValue}
         * @param metricValue The value to emit for the metric.
         *                    Can either be a literal number (typically "1"), or the name of a field in the structure
         *                    to take the value from the matched event. If you are using a field value, the field
         *                    value must have been matched using the pattern.
         *                    <p>
         *                    If you want to specify a field from a matched JSON structure, use '$.fieldName',
         *                    and make sure the field is in the pattern (if only as '$.fieldName = *').
         *                    <p>
         *                    If you want to specify a field from a matched space-delimited structure,
         *                    use '$fieldName'.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricValue(java.lang.String metricValue) {
            this.metricValue = metricValue;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MetricFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MetricFilterProps build() {
            return new Jsii$Proxy(logGroup, filterPattern, metricName, metricNamespace, defaultValue, metricValue);
        }
    }

    /**
     * An implementation for {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MetricFilterProps {
        private final software.amazon.awscdk.services.logs.ILogGroup logGroup;
        private final software.amazon.awscdk.services.logs.IFilterPattern filterPattern;
        private final java.lang.String metricName;
        private final java.lang.String metricNamespace;
        private final java.lang.Number defaultValue;
        private final java.lang.String metricValue;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.logGroup = software.amazon.jsii.Kernel.get(this, "logGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
            this.filterPattern = software.amazon.jsii.Kernel.get(this, "filterPattern", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.IFilterPattern.class));
            this.metricName = software.amazon.jsii.Kernel.get(this, "metricName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.metricNamespace = software.amazon.jsii.Kernel.get(this, "metricNamespace", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.defaultValue = software.amazon.jsii.Kernel.get(this, "defaultValue", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.metricValue = software.amazon.jsii.Kernel.get(this, "metricValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.logs.ILogGroup logGroup, final software.amazon.awscdk.services.logs.IFilterPattern filterPattern, final java.lang.String metricName, final java.lang.String metricNamespace, final java.lang.Number defaultValue, final java.lang.String metricValue) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.logGroup = java.util.Objects.requireNonNull(logGroup, "logGroup is required");
            this.filterPattern = java.util.Objects.requireNonNull(filterPattern, "filterPattern is required");
            this.metricName = java.util.Objects.requireNonNull(metricName, "metricName is required");
            this.metricNamespace = java.util.Objects.requireNonNull(metricNamespace, "metricNamespace is required");
            this.defaultValue = defaultValue;
            this.metricValue = metricValue;
        }

        @Override
        public final software.amazon.awscdk.services.logs.ILogGroup getLogGroup() {
            return this.logGroup;
        }

        @Override
        public final software.amazon.awscdk.services.logs.IFilterPattern getFilterPattern() {
            return this.filterPattern;
        }

        @Override
        public final java.lang.String getMetricName() {
            return this.metricName;
        }

        @Override
        public final java.lang.String getMetricNamespace() {
            return this.metricNamespace;
        }

        @Override
        public final java.lang.Number getDefaultValue() {
            return this.defaultValue;
        }

        @Override
        public final java.lang.String getMetricValue() {
            return this.metricValue;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("logGroup", om.valueToTree(this.getLogGroup()));
            data.set("filterPattern", om.valueToTree(this.getFilterPattern()));
            data.set("metricName", om.valueToTree(this.getMetricName()));
            data.set("metricNamespace", om.valueToTree(this.getMetricNamespace()));
            if (this.getDefaultValue() != null) {
                data.set("defaultValue", om.valueToTree(this.getDefaultValue()));
            }
            if (this.getMetricValue() != null) {
                data.set("metricValue", om.valueToTree(this.getMetricValue()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-logs.MetricFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MetricFilterProps.Jsii$Proxy that = (MetricFilterProps.Jsii$Proxy) o;

            if (!logGroup.equals(that.logGroup)) return false;
            if (!filterPattern.equals(that.filterPattern)) return false;
            if (!metricName.equals(that.metricName)) return false;
            if (!metricNamespace.equals(that.metricNamespace)) return false;
            if (this.defaultValue != null ? !this.defaultValue.equals(that.defaultValue) : that.defaultValue != null) return false;
            return this.metricValue != null ? this.metricValue.equals(that.metricValue) : that.metricValue == null;
        }

        @Override
        public final int hashCode() {
            int result = this.logGroup.hashCode();
            result = 31 * result + (this.filterPattern.hashCode());
            result = 31 * result + (this.metricName.hashCode());
            result = 31 * result + (this.metricNamespace.hashCode());
            result = 31 * result + (this.defaultValue != null ? this.defaultValue.hashCode() : 0);
            result = 31 * result + (this.metricValue != null ? this.metricValue.hashCode() : 0);
            return result;
        }
    }
}

==> logs-1.153.1-sources.jar: software/amazon/awscdk/services/logs/MetricFilterProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for a MetricFilter.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * MetricFilter.Builder.create(this, "MetricFilter")
 *         .logGroup(logGroup)
 *         .metricNamespace("MyApp")
 *         .metricName("Latency")
 *         .filterPattern(FilterPattern.exists("$.latency"))
 *         .metricValue("$.latency")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.57.0 (build f614666)", date = "2022-04-23T01:54:29.555Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.MetricFilterProps")
@software.amazon.jsii.Jsii.Proxy(MetricFilterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MetricFilterProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.logs.MetricFilterOptions {

    /**
     * The log group to create the filter on.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getLogGroup();

    /**
     * @return a {@link Builder} of {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MetricFilterProps> {
        software.amazon.awscdk.services.logs.ILogGroup logGroup;
        software.amazon.awscdk.services.logs.IFilterPattern filterPattern;
        java.lang.String metricName;
        java.lang.String metricNamespace;
        java.lang.Number defaultValue;
        java.lang.String metricValue;

        /**
         * Sets the value of {@link MetricFilterProps#getLogGroup}
         * @param logGroup The log group to create the filter on. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroup(software.amazon.awscdk.services.logs.ILogGroup logGroup) {
            this.logGroup = logGroup;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getFilterPattern}
         * @param filterPattern Pattern to search for log events. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filterPattern(software.amazon.awscdk.services.logs.IFilterPattern filterPattern) {
            this.filterPattern = filterPattern;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricName}
         * @param metricName The name of the metric to emit. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricName(java.lang.String metricName) {
            this.metricName = metricName;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricNamespace}
         * @param metricNamespace The namespace of the metric to emit. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricNamespace(java.lang.String metricNamespace) {
            this.metricNamespace = metricNamespace;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getDefaultValue}
         * @param defaultValue The value to emit if the pattern does not match a particular event.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultValue(java.lang.Number defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
         * Sets the value of {@link MetricFilterProps#getMetricValue}
         * @param metricValue The value to emit for the metric.
         *                    Can either be a literal number (typically "1"), or the name of a field in the structure
         *                    to take the value from the matched event. If you are using a field value, the field
         *                    value must have been matched using the pattern.
         *                    <p>
         *                    If you want to specify a field from a matched JSON structure, use '$.fieldName',
         *                    and make sure the field is in the pattern (if only as '$.fieldName = *').
         *                    <p>
         *                    If you want to specify a field from a matched space-delimited structure,
         *                    use '$fieldName'.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricValue(java.lang.String metricValue) {
            this.metricValue = metricValue;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MetricFilterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MetricFilterProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MetricFilterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MetricFilterProps {
        private final software.amazon.awscdk.services.logs.ILogGroup logGroup;
        private final software.amazon.awscdk.services.logs.IFilterPattern filterPattern;
        private final java.lang.String metricName;
        private final java.lang.String metricNamespace;
        private final java.lang.Number defaultValue;
        private final java.lang.String metricValue;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.logGroup = software.amazon.jsii.Kernel.get(this, "logGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
            this.filterPattern = software.amazon.jsii.Kernel.get(this, "filterPattern", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.IFilterPattern.class));
            this.metricName = software.amazon.jsii.Kernel.get(this, "metricName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.metricNamespace = software.amazon.jsii.Kernel.get(this, "metricNamespace", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.defaultValue = software.amazon.jsii.Kernel.get(this, "defaultValue", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.metricValue = software.amazon.jsii.Kernel.get(this, "metricValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.logGroup = java.util.Objects.requireNonNull(builder.logGroup, "logGroup is required");
            this.filterPattern = java.util.Objects.requireNonNull(builder.filterPattern, "filterPattern is required");
            this.metricName = java.util.Objects.requireNonNull(builder.metricName, "metricName is required");
            this.metricNamespace = java.util.Objects.requireNonNull(builder.metricNamespace, "metricNamespace is required");
            this.defaultValue = builder.defaultValue;
            this.metricValue = builder.metricValue;
        }

        @Override
        public final software.amazon.awscdk.services.logs.ILogGroup getLogGroup() {
            return this.logGroup;
        }

        @Override
        public final software.amazon.awscdk.services.logs.IFilterPattern getFilterPattern() {
            return this.filterPattern;
        }

        @Override
        public final java.lang.String getMetricName() {
            return this.metricName;
        }

        @Override
        public final java.lang.String getMetricNamespace() {
            return this.metricNamespace;
        }

        @Override
        public final java.lang.Number getDefaultValue() {
            return this.defaultValue;
        }

        @Override
        public final java.lang.String getMetricValue() {
            return this.metricValue;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("logGroup", om.valueToTree(this.getLogGroup()));
            data.set("filterPattern", om.valueToTree(this.getFilterPattern()));
            data.set("metricName", om.valueToTree(this.getMetricName()));
            data.set("metricNamespace", om.valueToTree(this.getMetricNamespace()));
            if (this.getDefaultValue() != null) {
                data.set("defaultValue", om.valueToTree(this.getDefaultValue()));
            }
            if (this.getMetricValue() != null) {
                data.set("metricValue", om.valueToTree(this.getMetricValue()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-logs.MetricFilterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MetricFilterProps.Jsii$Proxy that = (MetricFilterProps.Jsii$Proxy) o;

            if (!logGroup.equals(that.logGroup)) return false;
            if (!filterPattern.equals(that.filterPattern)) return false;
            if (!metricName.equals(that.metricName)) return false;
            if (!metricNamespace.equals(that.metricNamespace)) return false;
            if (this.defaultValue != null ? !this.defaultValue.equals(that.defaultValue) : that.defaultValue != null) return false;
            return this.metricValue != null ? this.metricValue.equals(that.metricValue) : that.metricValue == null;
        }

        @Override
        public final int hashCode() {
            int result = this.logGroup.hashCode();
            result = 31 * result + (this.filterPattern.hashCode());
            result = 31 * result + (this.metricName.hashCode());
            result = 31 * result + (this.metricNamespace.hashCode());
            result = 31 * result + (this.defaultValue != null ? this.defaultValue.hashCode() : 0);
            result = 31 * result + (this.metricValue != null ? this.metricValue.hashCode() : 0);
            return result;
        }
    }
}
